function cap = capvasicekatm(b,beta,sigma,r0,T0,delta,Tcap)
% In this exercise (Ex 6-3) we compute the cap price in the vasicek model
% dr(t)= (b+ beta r(t))dt+ sigma dW^*(t)


%% Bond Price at time 0 (using the affine structure of Vasicek model Ex 4-3)
funcA=  @(T) sigma^2*(4*exp(beta*T)-exp(2*beta*T)-2*beta*T-3)/(4*beta^3)+b*(exp(beta*T)-1-beta*T)/(beta^2);
funcB= @(T) (exp(beta*T)-1)/beta;
bondprice= @(T) exp(-funcA(T)-funcB(T)*r0);

%% Put price
% We first use Ex5-2) to find \sigma_{T,S}
% sigmap=\int_0^T \sigma^2_{T,S}(s)ds = \int_0^T (\int_T^S (\sigma exp(beta(u-s))) du)^2 ds
%sigmap = @(T,S) (4*exp(beta*S)*sigma^2*sinh(1/2*beta*(S-T))^2*sinh(beta*T))/(beta^3);
sigmap=@(T,S) sigma^2/(2*beta^3)*((exp(beta*(S-T))-1)^2*(exp(2*beta*T)-1));
d1 = @(T,S,K) (log(bondprice(S)/(K*bondprice(T)))+1/2*sigmap(T,S))/sqrt(sigmap(T,S));
d2 = @(T,S,K) (log(bondprice(S)/(K*bondprice(T)))-1/2*sigmap(T,S))/sqrt(sigmap(T,S));

putprice = @(T,S,K) K*bondprice(T)*normcdf(-d2(T,S,K))-bondprice(S)*normcdf(-d1(T,S,K)); 

%% ATM cap, cap rate = swap rate
tenor = T0:delta:Tcap;
kappa = (bondprice(T0)-bondprice(Tcap))/(delta*sum(bondprice(tenor(2:end))));


% EX 1-2) relation between CF of the caplet and put option
strikeprice = 1/(1+delta*kappa);
caplet = zeros(1,length(tenor)-1);
for j = 1:(length(tenor)-1)
    caplet(j)= putprice(tenor(j),tenor(j+1),strikeprice);
end
cap=sum(caplet)/strikeprice;
end