function [valueblack,valuemc]= liborcaplet
% In this exercise we compute the caplet price at time 0 with reset date
% T_{m-1}=(m-1)*T with cap rate kappa and settlement date T_m = m*T in a LIBOR market model
% with dL(t,T_m) = L(t,T_m) lambda* W^{T_{m+1}}_t

delta=1/4;
m=7;
lambda=0.1;
kappa=0.01;

% L(0,T_{m-1})
liborTmm1=0.09;
% P(0,T_m)
pTm= 0.85;
% number of Monte-Carlo simulations
N=10^7;
% Time T_{m-1}
Tmm1=(m-1)*delta;

%% Black's formula
d1= (log(liborTmm1/kappa)+1/2*lambda^2*Tmm1)/(sqrt(lambda^2*Tmm1));
d2= (log(liborTmm1/kappa)-1/2*lambda^2*Tmm1)/(sqrt(lambda^2*Tmm1));

valueblack= delta*pTm*(liborTmm1*normcdf(d1)-kappa*normcdf(d2));


%% Monte-Carlo simulation
% mean of log(L(T_{m-1},T_{m-1})
mu = log(liborTmm1)-1/2*lambda^2*(Tmm1);
% std of log(L(T_{m-1},T_{m-1})
sigma = sqrt(lambda^2*(Tmm1));
% generate log(L(T_{m-1},T_{m-1})
logofLtmm1= mu+sigma*randn(1,N);
% evaluation
valuemc= pTm*mean(delta*subplus((exp(logofLtmm1)-kappa)));
end